#!/usr/bin/env python

import os
import sys
import optparse
from ConfigParser import ConfigParser

import bitlyapi

pynotify = None
try:
    import pynotify
    pynotify.init('bitlyclip')
except ImportError, e:
    pass

def notify(message, cls='dialog-message'):
    print message
    if not pynotify:
        return False
    notif = pynotify.Notification("bitlyclip", message, cls)
    return notif.show()

def parse_args():
    p = optparse.OptionParser()
    p.add_option('-f', '--config', default='~/.bitly')
    return p.parse_args()

def main(url):
    opts, args = parse_args()

    config = ConfigParser()
    config.read(os.path.expanduser(opts.config))

    if not config.has_section('bitly'):
        msg = 'Failed to read bit.ly API configuration ' \
              'from %s.' % opts.config
        notify("%s failed.\n%s" % (__file__, msg), 'dialog-warning')
        sys.exit(1)

    api = bitlyapi.BitLy(
            config.get('bitly', 'api_user'),
            config.get('bitly', 'api_key'),
            )

    return api.shorten(longUrl=url)['url']

def cmd():
    try:
        #Copy from the clipboard
        url = os.popen('xsel').read()

        #BitLy magic
        short_url = main(url)

        #Paste to the clipboard
        os.popen('xsel -i', 'wb').write(short_url)
        notify('%s\n\n\tshortened to\n\n%s\n\n' % (url, short_url) +
               '\t(and put in your clipboard)')
    except Exception, e:
        notify("%s failed.\n%s" % (__file__, str(e)), 'dialog-warning')



from setuptools import setup, find_packages
import sys, os

version = '0.2.1'

setup(name='bitlyclip',
      version=version,
      description="bit.ly-fy a url in the X clipboard",
      long_description="""
      `bitlyclip` is just a script that:

        - takes a url in your clipboard
        - bitly-ifies it
        - puts the new url back in your clipboard

      It makes a nice 'hotkey' in whatever window manager you're using.

      If you have notify-python installed, it will
      pop up nice messages for you.

        - http://www.galago-project.org/downloads.php

      You'll need to have ``xsel`` on your system::

        $ sudo yum -y install xsel

      To install bitlyclip itself:  ``$ pip install bitlyclip``

      To use: ``$ bitlyclip``
      """,
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Intended Audience :: End Users/Desktop',
          'License :: OSI Approved :: GNU General Public License (GPL)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.5',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Topic :: Internet :: WWW/HTTP',
          'Topic :: Text Processing :: General',
      ],
      keywords='',
      author='Ralph Bean',
      author_email='rbean@redhat.com',
      url='http://github.com/ralphbean/bitlyclip',
      license='GPLv3+',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'bitlyapi',
      ],
      entry_points="""
      [console_scripts]
      bitlyclip = bitlyclip:cmd
      """,
     )
